@@ -10,10 +10,10 @@ from robin_sd_upload import _version
 from robin_sd_upload.slack_interaction import slack_handler
 from robin_sd_upload.supportive_scripts import yaml_parser
 from robin_sd_upload.supportive_scripts import logger
-from supportive_scripts import validate
-from supportive_scripts import create_zip
-from supportive_scripts import remove_zip
-from  supportive_scripts import check_upload_file
+from supportive_scripts.validate import validate
+from supportive_scripts.create_zip import create_zip
+from supportive_scripts.remove_zip import remove_zip
+from supportive_scripts.check_upload_file import check_upload_file
 
 def arg_parser():
     parser = argparse.ArgumentParser(
